import 'package:blink_trade/modules/verify-mobile/ui/signup.dart';
import 'package:blink_trade/screens/email_page.dart';
import 'package:blink_trade/widget/dropdown.dart';
import 'package:blink_trade/widget/pin.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:timer_count_down/timer_count_down.dart';

import '../../../main.dart';
import '../../../network/api_repository.dart';
import '../../../network/oauth_service.dart';
import '../../../utils/theme_files/app_colors.dart';
import '../../../widget/header.dart';

class OtpPage extends StatefulWidget {
  const OtpPage({super.key});

  @override
  State<OtpPage> createState() => _OtpPageState();
}

class _OtpPageState extends State<OtpPage> {
  bool timer = false;
  final ApiRepository _apiRepository = getIt<ApiRepository>();
  final OAuthService _oAuthService = getIt<OAuthService>();

  @override
  Widget build(BuildContext context) {
    final isLightMode = Theme.of(context).brightness == Brightness.light;

    RxBool isSwitched = false.obs;
    return SafeArea(
      child: SingleChildScrollView(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          mainAxisSize: MainAxisSize.min,
          children: [
            Header(),
            const SizedBox(height: 20),
            Text(
              'Verification code',
              style: TextStyle(
                color: AppColors.primaryContent(context),
                fontSize: 32,
                fontWeight: FontWeight.w600,
              ),
            ),
            const SizedBox(height: 20),
            Center(
              child: Text(
                'We have sent the code verifcation to\n your Mobile Number',
                style: TextStyle(
                  color: AppColors.primaryAccent(context),
                  fontSize: 15,
                  fontWeight: FontWeight.w400,
                ),
                textAlign: TextAlign.center,
              ),
            ),
            const SizedBox(height: 20),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  SignUpPage.phoneNumber,
                  style: TextStyle(
                      color: AppColors.primaryContent(context), fontSize: 18),
                ),
                Padding(
                  padding: const EdgeInsets.only(left: 2.0),
                  child: IconButton(
                      color: AppColors.primaryContent(context),
                      onPressed: () {},
                      icon: const Icon(
                        Icons.edit,
                        size: 18,
                      )),
                )
              ],
            ),
            const SizedBox(height: 20),
            const CodePin(),
            const SizedBox(height: 20),
            Center(
              child: Container(
                child: Countdown(
                  seconds: 30,
                  build: (BuildContext context, time) => Text(time.toString()),
                  interval: const Duration(seconds: 1),
                  onFinished: () {
                    setState(() {
                      timer = true;
                    });
                  },
                ),
              ),
            ),
            const SizedBox(height: 3),
            TextButton(
              onPressed: () {
                if (timer == true) {
                  null;
                  //code to send the code again
                } else {
                  null;
                }
              },
              child: Text(
                "Resend OTP",
                style: TextStyle(
                    color: AppColors.primaryColor(context), fontSize: 18),
              ),
            ),
            const SizedBox(height: 8),
            Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: 20,
              ),
              child: SizedBox(
                height: 50,
                child: ElevatedButton(
                  style: ElevatedButton.styleFrom(
                    primary: AppColors.primaryColor(context),
                    shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(4),
                    ),
                  ),
                  onPressed: () async {
                    // print(SignUpPage.phoneNumber);
                    // print(CodePin.code);
                    // print(SignUpPage.res['RefId']);
                    final res = await _oAuthService.verifyAuth(
                      SignUpPage.phoneNumber,
                      CodePin.code,
                      SignUpPage.res['RefId'],
                    );
                    //print("Verified Response $res[RefId]");
                    Navigator.push(
                      context,
                      MaterialPageRoute(builder: (context) => EmailPage()),
                    );
                  },
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: const [
                      Text(
                        "Verify",
                        style: TextStyle(
                          fontSize: 18,
                        ),
                      ),
                      SizedBox(width: 10),
                      Icon(
                        Icons.arrow_forward,
                      ),
                    ],
                  ),
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 20.0),
              child: Obx(
                () => Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Checkbox(
                      value: isSwitched.value,
                      onChanged: (val) {
                        isSwitched.value = val!;
                      },
                      side: BorderSide(
                        color: AppColors.primaryColor(context),
                      ),
                      activeColor: AppColors.primaryColor(context),
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(5),
                        side: BorderSide(
                          color: AppColors.primaryColor(context),
                        ),
                      ),
                    ),
                    const SizedBox(
                      height: 50,
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        const SizedBox(
                          height: 30,
                        ),
                        Text(
                          "I hereby declare that the mobile number",
                          style: TextStyle(
                              color: AppColors.primaryAccent(context),
                              fontSize: 15),
                          textAlign: TextAlign.left,
                        ),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.start,
                          children: [
                            Text(
                              "belong to ",
                              style: TextStyle(
                                  color: AppColors.primaryAccent(context),
                                  fontSize: 15),
                              textAlign: TextAlign.left,
                            ),
                            DropDown()
                          ],
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            ),
            Text(
              "Lorem ipsum | Lorem ipsum | Lorem ipsum\nCopyrights @ 2022 © Blink Trude. All Right Reserved",
              style: TextStyle(
                color: AppColors.primaryAccent(context),
                fontSize: 12,
                fontWeight: FontWeight.w400,
              ),
              textAlign: TextAlign.center,
            ),
            const SizedBox(height: 20),
            SizedBox(height: MediaQuery.of(context).viewInsets.bottom),
          ],
        ),
      ),
    );
  }
}
