import 'package:blink_trade/network/api_repository.dart';
import 'package:blink_trade/network/oauth_service.dart';
import 'package:blink_trade/widget/header.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:modal_bottom_sheet/modal_bottom_sheet.dart';

import '../../../main.dart';
import '../../../utils/theme_files/app_colors.dart';
import '../../../widget/textfield.dart';
import 'otp_page.dart';

class SignUpPage extends StatefulWidget {
  const SignUpPage({Key? key}) : super(key: key);
  static String phoneNumber = '';
  static dynamic res;

  @override
  State<SignUpPage> createState() => _SignUpPageState();
}

class _SignUpPageState extends State<SignUpPage> {
  final TextEditingController myController = TextEditingController();
  bool readOnly = false;

  final ApiRepository _apiRepository = getIt<ApiRepository>();
  final OAuthService _oAuthService = getIt<OAuthService>();

  @override
  void dispose() {
    myController.dispose();
    super.dispose();
  }

  void _onChanged(val) {
    setState(() {
      SignUpPage.phoneNumber = val;
    });
  }

  @override
  Widget build(BuildContext context) {
    final isLightMode = Theme.of(context).brightness == Brightness.light;
    return SafeArea(
      child: SingleChildScrollView(
        controller: ModalScrollController.of(context),
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 20),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Header(),
              //Header()
              const Text(
                'Signup Now',
                style: TextStyle(
                  //color: AppColors.textColor,
                  fontSize: 32,
                  fontWeight: FontWeight.w600,
                ),
              ),
              const SizedBox(height: 40),
              MyTextField(
                hint: "Enter Phone",
                controller: myController,
                prefixIcon: Row(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    SizedBox(
                      width: 10,
                    ),
                    const Text(
                      '+91',
                      style: TextStyle(
                        fontSize: 20,
                        fontWeight: FontWeight.w600,
                      ),
                    ),
                    const SizedBox(width: 10),
                    Text(
                      '|',
                      style: TextStyle(
                        fontSize: 20,
                        fontWeight: FontWeight.w600,
                        color: AppColors.primaryContent(context),
                      ),
                    ),
                    const SizedBox(width: 10),
                  ],
                ),
              ),
              const SizedBox(height: 15),
              Text(
                "You will receive an OTP on your number",
                style: TextStyle(
                  color: AppColors.primaryAccent(context),
                  fontSize: 14,
                  fontWeight: FontWeight.w400,
                ),
              ),
              const SizedBox(height: 30),
              Container(
                height: 50,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10),
                ),
                child: ElevatedButton(
                  style: ElevatedButton.styleFrom(
                    primary: AppColors.primaryColor(context),
                    shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(4),
                    ),
                  ),
                  onPressed: () async {
                    final res =
                        await _oAuthService.startAuth(myController.text);
                    print(res);
                    // print("Response $res");
                    print("Response ${res['RefId']}");
                    SignUpPage.res = res;
                    setState(() {
                      _onChanged(myController.text);
                    });

                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => OtpPage(),
                      ),
                    );
                    // Navigator.push(context,
                    //     MaterialPageRoute(builder: (context) => OtpPage()));
                    // Navigator.pushNamed(context, "/email-page");
                    //Get.to(() => Temp());
                  },
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: const [
                      Text(
                        "Continue",
                        style: TextStyle(
                          //    color: AppColors.textColor,
                          fontSize: 18,
                          fontWeight: FontWeight.w400,
                        ),
                      ),
                      SizedBox(width: 10),
                      Icon(
                        Icons.arrow_forward,
                        color: Colors.white,
                      ),
                    ],
                  ),
                ),
              ),
              const SizedBox(height: 10),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Theme(
                    data: Theme.of(context).copyWith(
                      unselectedWidgetColor: AppColors.primaryColor(context),
                    ),
                    child: Checkbox(
                      value: true,
                      onChanged: (val) {},
                      activeColor: AppColors.primaryColor(context),
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(5),
                          side: BorderSide(
                              color: AppColors.primaryAccent(context))),
                    ),
                  ),
                  RichText(
                    text: TextSpan(
                      text: "Enable WhatsApp Notification ",
                      style: TextStyle(
                        color: AppColors.primaryAccent(context),
                        fontSize: 14,
                        fontWeight: FontWeight.w500,
                      ),
                      children: [
                        TextSpan(
                          text: "T&Cs",
                          style: TextStyle(
                            color: AppColors.primaryColor(context),
                            fontSize: 14,
                            fontWeight: FontWeight.w500,
                            decoration: TextDecoration.underline,
                          ),
                          recognizer: TapGestureRecognizer()
                            ..onTap = () {
                              print("T&C");
                            },
                        ),
                      ],
                    ),
                  ),
                ],
              ),
              Text(
                "Lorem ipsum | Lorem ipsum | Lorem ipsum\nCopyrights @ 2022 © Blink Trude. All Right Reserved",
                style: TextStyle(
                  color: AppColors.primaryAccent(context),
                  fontSize: 12,
                ),
                textAlign: TextAlign.center,
              ),
              const SizedBox(height: 20),
              SizedBox(height: MediaQuery.of(context).viewInsets.bottom),
            ],
          ),
        ),
      ),
    );
  }
}
